//------------------------------------------------------------------------------
// TestView.cpp
//------------------------------------------------------------------------------
// Test is a sample application. It's main purpose is to show how to use the
// ListItem implementation in order to display a tree of icons with their labels.
//------------------------------------------------------------------------------
// I N C L U D E S
//------------------------------------------------------------------------------

#include "IconListItem.h"
#include "TestView.h"

//------------------------------------------------------------------------------
// I M P L E M E N T A T I O N
//------------------------------------------------------------------------------

TestView::TestView(BRect rect)
	: BView(rect, "TestView", B_FOLLOW_ALL, B_WILL_DRAW)
{
	List = new BOutlineListView(Bounds(), "List");

	// Here we're going to get the mini icon from a specific mime type
	BRect _rect(0.0, 0.0, 15.0, 15.0); 
	BBitmap *icon = new BBitmap(_rect, B_CMAP8);
	
	BMimeType mime("application/x-vnd.Be-root");
	mime.GetIcon(icon, B_MINI_ICON);

	// And now we're going to display the icon by using our new class
	IconListItem *ili = new IconListItem(icon,"Hello Icons !", 0, false); 
	List->AddItem(ili); 

	// The following code will display every icons and labels from the
	// "/boot/demos" folder
	BString	directory("/boot/demos");
	BDirectory dir(directory.String());
	BEntry ent;
	entry_ref ref;
	char filename[B_FILE_NAME_LENGTH];

	while (dir.GetNextEntry(&ent) == B_NO_ERROR)
	{
		ent.GetRef(&ref);
		ent.GetName(filename);

		BNode MyNode(&ref);
		if(MyNode.InitCheck() != B_NO_ERROR)
		{
			printf("Could not create node\n");
		}
		BNodeInfo MyNodeInfo(&MyNode);
		if(MyNodeInfo.InitCheck() != B_NO_ERROR)
		{
			printf("Could not create node info\n");
		}
		if(MyNodeInfo.GetTrackerIcon(icon, B_MINI_ICON) == B_NO_ERROR)
		{
			IconListItem *ili2 = new IconListItem(icon,filename, 1, false); 
			List->AddItem(ili2); 
		}
	}

	// We're going to display others icons using different mime type.
	// This is just for fun ! :)
	BMimeType mime3("application/x-vnd.Be-directory");
	mime3.GetIcon(icon, B_MINI_ICON);

	IconListItem *ili3 = new IconListItem(icon,"Hello World !", 1, true); 
	List->AddItem(ili3); 

	IconListItem *ili4 = new IconListItem(icon,"0123456789", 2, true); 
	List->AddItem(ili4);
	
	BMimeType mime4("application/x-vnd.Be-elfexecutable");
	mime4.GetIcon(icon, B_MINI_ICON);
	
	IconListItem *ili5 = new IconListItem(icon,"Yeah...", 0, true); 
	List->AddItem(ili5); 

	BMimeType mime5("application/x-vnd.Furix-IconListItem");
	mime5.GetIcon(icon, B_MINI_ICON);
	 
	IconListItem *ili6 = new IconListItem(icon,"It seems to work pretty well...", 1, true); 
	List->AddItem(ili6);
 
	AddChild(new BScrollView("scroll", List, B_FOLLOW_ALL, 0,false,true));
	
	delete icon;
}

TestView::~TestView() {
	void *item; 
	for (int32 i = 0; item = List->ItemAt(i); i++ ) 
		delete item;
	delete List;
}
//-------------------------------------------------------------- TestView.cpp --